================================
django Organice |latest-version|
================================

|travis-ci| |health| |downloads| |license| |gitter|

All-in-one collaboration solution.  For non-profit organizations, sports clubs, small to
medium-sized businesses.

django Organice is a nice way to run a collaboration platform, an intranet, and websites for your
business.  It's a compilation of the best Django packages, preconfigured for getting you started
quickly.  Being powered by the well-known `Django Web framework`_ it's a safe choice for your IT
investment providing an easily extensible architecture.


.. |latest-version| image:: https://img.shields.io/pypi/v/django-organice.svg
   :alt: Latest version on PyPI
   :target: https://pypi.python.org/pypi/django-organice
.. |travis-ci| image:: https://travis-ci.org/Organice/django-organice.svg
   :alt: Build status
   :target: https://travis-ci.org/Organice/django-organice
.. |health| image:: https://landscape.io/github/Organice/django-organice/master/landscape.svg?style=flat
   :target: https://landscape.io/github/Organice/django-organice/master
   :alt: Code health
.. |downloads| image:: https://img.shields.io/pypi/dm/django-organice.svg
   :alt: Monthly downloads from PyPI
   :target: https://pypi.python.org/pypi/django-organice
.. |license| image:: https://img.shields.io/pypi/l/django-organice.svg
   :alt: Software license
   :target: https://www.apache.org/licenses/LICENSE-2.0.html
.. |gitter| image:: https://badges.gitter.im/Join%20Chat.svg
   :alt: Gitter chat room
   :target: https://gitter.im/Organice/chat
.. _Django Web framework: https://www.djangoproject.com/

Fundamental Features
====================

- Enables everyone to contribute to your content---while retaining your full control.
- Supports all four common collaboration and support patterns in several ways:

  #. *Active contribution* (create content, contribute corrections)
  #. *Passive contribution* (report issues, assign tasks, provide feedback)
  #. *Active consumption* (search and browse for content)
  #. *Passive consumption* (subscribe to notifications)

- Continually involves, helps and optimally supports your collaborators by sending out reminders,
  editing and submission hints to avoid losing traction or interest.

Core Components
===============

Major components of django Organice are:

- Django Web framework
- full-featured content management (django CMS)
- full-featured versatile blog (Zinnia, cmsplugin)
- events with event calendar (via Zinnia)
- flexible contact pages (cmsplugin)
- link collection pages
- full-featured newsletter (Emencia)
- todo/issue lists
- social login and user profiles (allauth)
- generic analytics support (analytical)
- web analytics respecting your privacy (Piwik integration)
- multiple themes (available for free at http://organice.io/themes)
- multi-language support
- multiple websites support
- database support for PostgreSQL, MySQL, Oracle, and more

Roadmap
=======

We are thrilled to get these awesome features out to you:

- group spaces with automatic mailing list (groupname@example.com)
- documentation area / wiki (probably by use of CMS functionality)
- discussion forum / Q&A board (Askbot, Misago)
- content download for magazine generation
- unobtrusive, integrated, transparent document and asset management
- DropBox, ownCloud, Windows OneDrive, Google Drive, Apple iCloud, etc. integration
- fully integrated search (Haystack)
- live chat or chat integration
- surveys (django-crowdsourcing, ntusurvey)

Who is using django Organice?
=============================

Examples of websites running django Organice:

- `Organice.io website <http://organice.io/>`_
- `Organice demo site <http://demo.organice.io/>`_
- `Kreuzlingen Rudolf Steiner school <http://www.rssk.ch/>`_

Download and Contributions
==========================

Official repositories: (kept in sync)

#. Bitbucket: https://bitbucket.org/organice/django-organice
#. GitHub: https://github.com/organice/django-organice

Getting Help
============

- Documentation is available at http://docs.organice.io
- Questions? Please use `StackOverflow`_.  Tag your questions with ``django-organice``.
- Found a bug? Please use either the `Bitbucket`_ or `GitHub`_ issue tracker (you choose)
- Need support? You're welcome to use our `Gitter chat room`_.


.. _StackOverflow: http://stackoverflow.com/questions/tagged/django-organice
.. _Bitbucket: https://bitbucket.org/organice/django-organice/issues
.. _GitHub: https://github.com/Organice/django-organice/issues
.. _Gitter chat room: https://gitter.im/Organice/chat
